import React, { lazy, Suspense, useState, useEffect } from 'react';
import { BrowserRouter as Router, Routes, Route, useLocation } from 'react-router-dom';
import { AnimatePresence } from 'framer-motion';
import Navbar from './components/Navbar';
import Footer from './components/Footer';
import { ToastContainer } from './components/ToastContainer';
import { useToast } from './hooks/useToast';
import ScrollToTop from './components/ScrollToTop';
import MetaTags from './components/MetaTags';
import SubscriptionPopup from './components/SubscriptionPopup';
import { useExitIntent } from './hooks/useExitIntent';

// Lazy load pages
const Home = lazy(() => import('./pages/Home'));
const Services = lazy(() => import('./pages/Services'));
const Blog = lazy(() => import('./pages/Blog'));
const About = lazy(() => import('./pages/About'));
const EarlyAccess = lazy(() => import('./pages/EarlyAccess'));
const FormSuccess = lazy(() => import('./pages/FormSuccess'));
const PrivacyPolicy = lazy(() => import('./pages/legal/PrivacyPolicy'));
const CookiePolicy = lazy(() => import('./pages/legal/CookiePolicy'));
const TermsOfService = lazy(() => import('./pages/legal/TermsOfService'));
const NotFound = lazy(() => import('./pages/NotFound'));

// Loading fallback
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="animate-spin rounded-full h-8 w-8 border-b-2 border-teal-600"></div>
  </div>
);

function AppContent() {
  const { toasts, removeToast } = useToast();
  const location = useLocation();
  const [hasUserInteracted, setHasUserInteracted] = useState(false);
  
  // Use the exit intent hook with enhanced detection and continuous mode
  const { showExitIntent, resetExitIntent } = useExitIntent({
    threshold: 5, // Set threshold to 5px from top of viewport
    maxDisplayCount: 999, // High number to allow many displays
    cookieName: 'dd_exit_intent_shown',
    cookieExpiration: 1, // 1 day
    continuous: true // Enable continuous mode to show popup every time
  });

  // Debug exit intent detection
  useEffect(() => {
    if (showExitIntent) {
      console.log('Exit intent detected and popup should show');
    }
  }, [showExitIntent]);

  // Set user interaction state
  useEffect(() => {
    const handleInteraction = () => {
      setHasUserInteracted(true);
    };

    // Add event listeners for user interaction
    document.addEventListener('mousedown', handleInteraction, { passive: true });
    document.addEventListener('keydown', handleInteraction, { passive: true });
    document.addEventListener('touchstart', handleInteraction, { passive: true });
    document.addEventListener('scroll', handleInteraction, { passive: true });
    
    // Set a timer to consider the user as "interacted" after 1 second
    // This helps with the initial page load
    const timer = setTimeout(() => {
      setHasUserInteracted(true);
    }, 1000);

    return () => {
      document.removeEventListener('mousedown', handleInteraction);
      document.removeEventListener('keydown', handleInteraction);
      document.removeEventListener('touchstart', handleInteraction);
      document.removeEventListener('scroll', handleInteraction);
      clearTimeout(timer);
    };
  }, []);

  // Handle popup close
  const handleClosePopup = () => {
    resetExitIntent();
    
    // In continuous mode, we don't set a cookie to prevent showing again
    // This allows the popup to appear again when the cursor moves to the browser tabs
  };

  // Check if current route should show layout
  const shouldShowLayout = ![
    '*',
    '/404',
    '/success'
  ].includes(location.pathname) && !location.pathname.endsWith('/404');

  // Don't show exit intent on certain pages
  const shouldShowExitIntentOnCurrentPage = ![
    '/early-access',
    '/success'
  ].includes(location.pathname);

  // Determine if popup should be shown
  const shouldShowPopup = showExitIntent && 
                          hasUserInteracted && 
                          shouldShowExitIntentOnCurrentPage;

  return (
    <div className="flex flex-col min-h-screen">
      <MetaTags />
      {shouldShowLayout && <Navbar />}
      <main className={`flex-grow ${shouldShowLayout ? 'pt-16' : ''}`}>
        <AnimatePresence mode="wait">
          <Suspense fallback={<PageLoader />}>
            <Routes>
              {/* Public routes */}
              <Route path="/" element={<Home />} />
              <Route path="/services" element={<Services />} />
              <Route path="/blog" element={<Blog />} />
              <Route path="/about" element={<About />} />
              <Route path="/early-access" element={<EarlyAccess />} />
              <Route path="/success" element={<FormSuccess />} />
              <Route path="/privacy-policy" element={<PrivacyPolicy />} />
              <Route path="/cookie-policy" element={<CookiePolicy />} />
              <Route path="/terms-of-service" element={<TermsOfService />} />

              {/* 404 route - must be last */}
              <Route path="*" element={<NotFound />} />
            </Routes>
          </Suspense>
        </AnimatePresence>
      </main>
      {shouldShowLayout && <Footer />}
      <ToastContainer toasts={toasts} onRemove={removeToast} />
      {shouldShowLayout && <ScrollToTop />}

      {/* Subscription Popup */}
      <AnimatePresence>
        {shouldShowPopup && (
          <SubscriptionPopup onClose={handleClosePopup} />
        )}
      </AnimatePresence>
    </div>
  );
}

export default function App() {
  return (
    <Router>
      <AppContent />
    </Router>
  );
}